@@ -21,7 +21,7 @@ class CrudSchema(BaseSchema):
     TRIM_NULL_VALUES = False  # TODO
     PAGE_SIZE = 0
 
-    def __init__(self, filters, initkwargs=None):
+    def __init__(self, filters, q_filters, initkwargs=None):
         # self.url_path = self.URL_PATH
         self.path = self.PATH
         self.model_class = self.MODEL_CLASS
@@ -46,7 +46,7 @@ class CrudSchema(BaseSchema):
             # Order by Anchor if no ordering sent
             self.ORDER_BY = [self.ANCHOR]
 
-        self.filters = filters if filters else {}
+        self.set_filters(filters=filters, q_filters=q_filters)
 
         if self.FIELDS:
             if self.ANCHOR not in self.FIELDS:
@@ -58,8 +58,12 @@ class CrudSchema(BaseSchema):
         self.annotations = self.ANNOTATIONS
         self.required_fields = [f.name for f in self.fields_data if not f.blank]
 
+    def set_filters(self, filters=None, q_filters=None):
+        self.filters = filters if filters else {}
+        self.q_filters = q_filters if q_filters else []
+
     def get_queryset(self):
-        return self.model_class.objects.filter(**self.filters).order_by(*self.ORDER_BY)
+        return self.model_class.objects.filter(**self.filters, *self.q_filters).order_by(*self.ORDER_BY)
 
     def get(self):
         if not (self.GET or self.POST or self.PUT):
@@ -110,7 +114,7 @@ class CrudSchema(BaseSchema):
             ids = ','.join(str(i) for i in ids)
             exec(f'self.item.{field}.add({ids})')
 
-        self.filters = {'id': self.item.id}
+        self.set_filters(filters={'id': self.item.id})
         return self.get()
 
     def bulk_post(self, data, force=False, **kwargs):
@@ -130,7 +134,7 @@ class CrudSchema(BaseSchema):
             self.model_class.objects.bulk_create([self.model_class(**item, **kwargs) for item in data])
             ln = len(data)
             item_ids = list(self.model_class.objects.order_by('-id')[:ln].values_list('id', flat=True))
-        self.filters = {'id__in': item_ids}
+        self.set_filters(filters={'id__in': item_ids})
         return self.get()
 
     def put(self, **data):
@@ -146,13 +150,9 @@ class CrudSchema(BaseSchema):
                     many_models_data[item.id].append((field, data.pop(field)))
                 else:
                     many_models_data.pop(item.id)
-            print('in put ')
-            for key, value in data.items():
-                print(key, value)
-                setattr(item, key, value)
 
-            print(data)
-            print(item.editor)
+            for key, value in data.items():
+                setattr(item, key, value)
             item.full_clean()
             res.append(item)
 
@@ -167,7 +167,7 @@ class CrudSchema(BaseSchema):
 
         if not item_ids:
             raise Error(field_name='id', message='Item(s) not found.', status=HttpStatus.HTTP_404_NOT_FOUND)
-        self.filters = {'id__in': item_ids}
+        self.set_filters(filters={'id__in': item_ids})
         return self.get()
 
     def delete(self, **data):
